@@ -662,7 +662,7 @@ class Route(RTNL_Object):
                    .fetch('SELECT * FROM enc_mpls WHERE f_route_id = %s' %
                           (self.schema.plch, ), (self['route_id'], )))
             enc = tuple(enc)
-            if len(enc):
+            if enc:
                 na = [Target(x) for x in json.loads(enc[0][2])]
                 self.load_value('encap', na)
 
@@ -679,7 +679,7 @@ class Route(RTNL_Object):
                        .fetch('SELECT * FROM metrics WHERE f_route_id = %s' %
                               (self.schema.plch, ), (self['route_id'], )))
 
-            if len(tuple(metrics)):
+            if tuple(metrics):
                 self['metrics'] = Metrics(self,
                                           self.view,
                                           {'route_id': self['route_id']},
